==> qt6_applications-6.0.0.2.2-py3-none-macosx_10_14_x86_64.whl: qt6_applications-6.0.0.2.2.data/purelib/qt6_applications/_applications.py <==
# to be generated a package build time
application_paths = {
    'assistant': 'Assistant.app',
    'designer': 'Designer.app',
    'linguist': 'Linguist.app',
    'androiddeployqt': 'androiddeployqt',
    'androidtestrunner': 'androidtestrunner',
    'cmake_automoc_parser': 'cmake_automoc_parser',
    'lconvert': 'lconvert',
    'licheck_mac': 'licheck_mac',
    'lprodump': 'lprodump',
    'lrelease': 'lrelease',
    'lrelease-pro': 'lrelease-pro',
    'lupdate': 'lupdate',
    'lupdate-pro': 'lupdate-pro',
    'macdeployqt': 'macdeployqt',
    'moc': 'moc',
    'pixeltool': 'pixeltool.app',
    'qdbus': 'qdbus',
    'qdbuscpp2xml': 'qdbuscpp2xml',
    'qdbusviewer': 'qdbusviewer.app',
    'qdbusxml2cpp': 'qdbusxml2cpp',
    'qdistancefieldgenerator': 'qdistancefieldgenerator',
    'qdoc': 'qdoc',
    'qhelpgenerator': 'qhelpgenerator',
    'qlalr': 'qlalr',
    'qmake': 'qmake',
    'qml': 'qml',
    'qmlcachegen': 'qmlcachegen',
    'qmleasing': 'qmleasing',
    'qmlformat': 'qmlformat',
    'qmlimportscanner': 'qmlimportscanner',
    'qmllint': 'qmllint',
    'qmlplugindump': 'qmlplugindump',
    'qmlpreview': 'qmlpreview',
    'qmlprofiler': 'qmlprofiler',
    'qmlscene': 'qmlscene',
    'qmltestrunner': 'qmltestrunner',
    'qmltime': 'qmltime.app',
    'qmltyperegistrar': 'qmltyperegistrar',
    'qt-cmake': 'qt-cmake',
    'qt-cmake-private': 'qt-cmake-private',
    'qt-cmake-standalone-test': 'qt-cmake-standalone-test',
    'qt-configure-module': 'qt-configure-module',
    'qt-internal-configure-tests': 'qt-internal-configure-tests',
    'qtattributionsscanner': 'qtattributionsscanner',
    'qtdiag': 'qtdiag',
    'qtpaths': 'qtpaths',
    'qtplugininfo': 'qtplugininfo',
    'qvkgen': 'qvkgen',
    'rcc': 'rcc',
    'tracegen': 'tracegen',
    'uic': 'uic',
}

==> qt6_applications-6.0.3.2.2-py3-none-macosx_10_14_x86_64.whl: qt6_applications-6.0.3.2.2.data/purelib/qt6_applications/_applications.py <==
# to be generated a package build time
application_paths = {
    'assistant': 'Assistant.app',
    'designer': 'Designer.app',
    'linguist': 'Linguist.app',
    'androiddeployqt': 'androiddeployqt',
    'androidtestrunner': 'androidtestrunner',
    'cmake_automoc_parser': 'cmake_automoc_parser',
    'lconvert': 'lconvert',
    'licheck_mac': 'licheck_mac',
    'lprodump': 'lprodump',
    'lrelease': 'lrelease',
    'lrelease-pro': 'lrelease-pro',
    'lupdate': 'lupdate',
    'lupdate-pro': 'lupdate-pro',
    'macdeployqt': 'macdeployqt',
    'moc': 'moc',
    'pixeltool': 'pixeltool.app',
    'qdbus': 'qdbus',
    'qdbuscpp2xml': 'qdbuscpp2xml',
    'qdbusviewer': 'qdbusviewer.app',
    'qdbusxml2cpp': 'qdbusxml2cpp',
    'qdistancefieldgenerator': 'qdistancefieldgenerator',
    'qdoc': 'qdoc',
    'qhelpgenerator': 'qhelpgenerator',
    'qlalr': 'qlalr',
    'qmake': 'qmake',
    'qml': 'qml',
    'qmlcachegen': 'qmlcachegen',
    'qmleasing': 'qmleasing',
    'qmlformat': 'qmlformat',
    'qmlimportscanner': 'qmlimportscanner',
    'qmllint': 'qmllint',
    'qmlplugindump': 'qmlplugindump',
    'qmlpreview': 'qmlpreview',
    'qmlprofiler': 'qmlprofiler',
    'qmlscene': 'qmlscene',
    'qmltestrunner': 'qmltestrunner',
    'qmltime': 'qmltime',
    'qmltyperegistrar': 'qmltyperegistrar',
    'qt-cmake': 'qt-cmake',
    'qt-cmake-private': 'qt-cmake-private',
    'qt-cmake-standalone-test': 'qt-cmake-standalone-test',
    'qt-configure-module': 'qt-configure-module',
    'qt-internal-configure-tests': 'qt-internal-configure-tests',
    'qtattributionsscanner': 'qtattributionsscanner',
    'qtdiag': 'qtdiag',
    'qtpaths': 'qtpaths',
    'qtplugininfo': 'qtplugininfo',
    'qvkgen': 'qvkgen',
    'rcc': 'rcc',
    'tracegen': 'tracegen',
    'uic': 'uic',
}
